<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>AppSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="42"/>
        <source>Check transfer application will automatically install the corresponding UOS version of the application.</source>
        <translation>Kiểm tra ứng dụng chuyển sẽ tự động cài đặt phiên bản ứng dụng tương ứng của UOS.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Application</source>
        <translation>Ứng dụng</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Recommendation</source>
        <translation>Khuyến nghị</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="102"/>
        <source>Transferable</source>
        <translation>Chuyển được</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="112"/>
        <source>Not Suitable</source>
        <translation>Không phù hợp</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="46"/>
        <source>Select apps to transfer</source>
        <translation>Chọn ứng dụng để chuyển</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="47"/>
        <source>Please select the applications to back up</source>
        <translation>Vui lòng chọn các ứng dụng để sao lưu</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="86"/>
        <source>UOS data transfer</source>
        <translation>Chuyển dữ liệu UOS</translation>
    </message>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="91"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to UOS, helping you seamlessly replace your system.</source>
        <translation>Công cụ chuyển UOS giúp di chuyển một cách nhanh chóng các tệp, dữ liệu cá nhân và ứng dụng của bạn sang UOS, giúp bạn thay thế hệ thống một cách mượt mà.</translation>
    </message>
</context>
<context>
    <name>ChooseWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="35"/>
        <source>Export to local directory</source>
        <translation>Xuất sang thư mục cục bộ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="41"/>
        <source>Select a transfer way</source>
        <translation>Chọn cách chuyển</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="56"/>
        <source>Unable to connect to the network， please check your network connection or select export to local directory.</source>
        <translation>Không thể kết nối với mạng, vui lòng kiểm tra kết nối mạng hoặc chọn xuất sang thư mục cục bộ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="69"/>
        <source>Next</source>
        <translation>Tiếp theo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="33"/>
        <source>From Windows PC</source>
        <translation>Từ máy tính Windows</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="39"/>
        <source>Import from backup files</source>
        <translation>Nhập từ tệp sao lưu</translation>
    </message>
</context>
<context>
    <name>ConfigSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="39"/>
        <source>Check transfer configuration will automatically apply to UOS.</source>
        <translation>Kiểm tra cấu hình chuyển sẽ tự động áp dụng cho UOS.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <source>Browser bookmarks</source>
        <translation>Lưu danh sách trang web</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Recommendation</source>
        <translation>Khuyến nghị</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="98"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="139"/>
        <source>Transferable</source>
        <translation>Chuyển được</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Personal Settings</source>
        <translation>Cài đặt cá nhân</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="138"/>
        <source>Customized Wallpaper</source>
        <translation>Nền màn hình tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="49"/>
        <source>Select the configuration to transfer</source>
        <translation>Chọn cấu hình để chuyển</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="50"/>
        <source>Please select the configurations to back up</source>
        <translation>Vui lòng chọn các cấu hình để sao lưu</translation>
    </message>
</context>
<context>
    <name>ConnectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="36"/>
        <source>Ready to connect</source>
        <translation>Sẵn sàng kết nối</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="41"/>
        <source>Please open data transfer on Windows, and imput the IP and connect code</source>
        <translation>Vui lòng mở công cụ chuyển dữ liệu trên Windows, và nhập địa chỉ IP và mã kết nối</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="48"/>
        <source>Download Windows client</source>
        <translation>Tải xuống ứng dụng Windows</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="59"/>
        <source>Connect code is expired, please refresh for new code</source>
        <translation>Mã kết nối đã hết hạn, vui lòng làm mới để nhận mã mới</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="75"/>
        <source>Back</source>
        <translation>Quay lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="104"/>
        <source>computer</source>
        <translation>máy tính</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="107"/>
        <source>Local IP</source>
        <translation>IP địa phương</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="163"/>
        <source>Refresh</source>
        <translation>Làm mới</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>The code will be expired in</source>
        <translation>Mã sẽ hết hạn sau</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>please input connect code as soon as possible</source>
        <translation>vui lòng nhập mã kết nối ngay lập tức</translation>
    </message>
</context>
<context>
    <name>CreateBackupFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="87"/>
        <source>Create data backup</source>
        <translation>Tạo bản sao lưu dữ liệu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="95"/>
        <source>File information</source>
        <translation>Thông tin tệp</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="115"/>
        <source>Name</source>
        <translation>Tên</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="133"/>
        <source>size:0B</source>
        <translation>kích thước:0B</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="152"/>
        <source>Location</source>
        <translation>Vị trí</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="162"/>
        <source>(Select Backup Disk)</source>
        <translation>(Chọn ổ đĩa sao lưu)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="187"/>
        <source>Insufficient space in the selected disk, please clean the space</source>
        <translation>Không đủ không gian trong ổ đĩa được chọn, vui lòng xóa không gian</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="195"/>
        <source>Backup</source>
        <translation>Sao lưu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="339"/>
        <source>Size:%1</source>
        <translation>Kích thước:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="382"/>
        <source>local disk</source>
        <translation>ổ đĩa địa phương</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="388"/>
        <source>%1/%2 available</source>
        <translation>&apos;%1/%2 có sẵn&apos;</translation>
    </message>
</context>
<context>
    <name>CustomMessageBox</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="66"/>
        <source>Reselect</source>
        <translation>Chọn lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="81"/>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>The presence of outstanding transfer tasks between you and the target device has been detected.</source>
        <translation>Đã phát hiện có các nhiệm vụ chuyển dữ liệu chưa hoàn tất giữa bạn và thiết bị đích.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>Do you want to continue with the last transfer?</source>
        <translation>Bạn có muốn tiếp tục với lần chuyển dữ liệu trước?</translation>
    </message>
</context>
<context>
    <name>ErrorWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="54"/>
        <source>Transfer will be completed in</source>
        <translation>Chuyển dữ liệu sẽ hoàn tất trong</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="69"/>
        <source>Try again</source>
        <translation>Thử lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="66"/>
        <source>Back</source>
        <translation>Lỗi mạng</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="29"/>
        <source>Network Error</source>
        <translation>Chuyển dữ liệu bị gián đoạn</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="30"/>
        <source>Transfer interrupted</source>
        <translation>Mạng đã bị ngắt, chuyển dữ liệu thất bại, vui lòng kết nối mạng và thử lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="32"/>
        <source>The network disconnected, transfer failed, please connect the network and try again</source>
        <translation>Không đủ không gian trong UOS, vui lòng xóa ít nhất %1 GB và thử lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="34"/>
        <source>Insufficient space in UOS, please clear at least %1 GB and try again</source>
        <translation>Không đủ không gian trong UOS, vui lòng xóa ít nhất %1 GB và thử lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="36"/>
        <source>Insufficient space in UOS, Please reserve enough space</source>
        <translation>Không đủ không gian trong UOS, vui lòng để trống đủ không gian</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Name</source>
        <translation>Tên</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Size</source>
        <translation>Kích thước</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="60"/>
        <source>When transfer completed, the data will be placed in the user&apos;s home directory</source>
        <translation>Khi quá trình chuyển dữ liệu hoàn tất, dữ liệu sẽ được đặt trong thư mục nhà của người dùng</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="73"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="71"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="56"/>
        <source>Select the file to transfer</source>
        <translation>Chọn tệp để chuyển</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="57"/>
        <source>Please select the files to back up</source>
        <translation>Vui lòng chọn các tệp để sao lưu</translation>
    </message>
</context>
<context>
    <name>NetworkDisconnectionWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="34"/>
        <source>The network has been disconnected. Please check your network</source>
        <translation>Mạng đã bị ngắt kết nối. Vui lòng kiểm tra lại mạng của bạn</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="40"/>
        <source>Back</source>
        <translation>Quay lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="41"/>
        <source>Try again</source>
        <translation>Thử lại</translation>
    </message>
</context>
<context>
    <name>ProcessWindow</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="297"/>
        <source>Installing</source>
        <translation>Đang cài đặt</translation>
    </message>
</context>
<context>
    <name>PromptWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="29"/>
        <source>Before tranfer</source>
        <translation>Trước khi chuyển</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="34"/>
        <source>Data transfer requires some time, to avoid interrupting the migration due to low battery, please keep connect to the  power.</source>
        <translation>Chuyển dữ liệu cần một khoảng thời gian nhất định, để tránh gián đoạn quá trình di chuyển do pin yếu, vui lòng tiếp tục kết nối với nguồn điện.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="36"/>
        <source>Other applications may slowdown the transfer speed. For smoother experience, please close other applications.</source>
        <translation>Các ứng dụng khác có thể làm chậm tốc độ truyền dữ liệu. Để trải nghiệm mượt mà hơn, vui lòng đóng các ứng dụng khác.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="38"/>
        <source>For the security of your transfer, please use a trusted network.</source>
        <translation>Để đảm bảo an toàn cho việc chuyển dữ liệu, vui lòng sử dụng mạng đáng tin cậy.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Quay lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="64"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
<context>
    <name>ReadyWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="48"/>
        <source>Ready to connect</source>
        <translation>Sẵn sàng để kết nối</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="52"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="59"/>
        <source>Please input the IP of UOS</source>
        <translation>Vui lòng nhập địa chỉ IP của UOS</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="79"/>
        <source>Please open data transfer on UOS, and get the IP</source>
        <translation>Vui lòng mở chuyển dữ liệu trên UOS và lấy địa chỉ IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="85"/>
        <source>Connect code</source>
        <translation>Mã kết nối</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="95"/>
        <source>Please input the connect code on UOS</source>
        <translation>Vui lòng nhập mã kết nối trên UOS</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="118"/>
        <source>Back</source>
        <translation>Quay lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="33"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="112"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="167"/>
        <source>connect...</source>
        <translation>Kết nối...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="120"/>
        <source>Connect</source>
        <translation>Kết nối</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="258"/>
        <source>Failed to connect, please check your input</source>
        <translation>Không thể kết nối, vui lòng kiểm tra lại thông tin đầu vào</translation>
    </message>
</context>
<context>
    <name>ResultDisplayWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="128"/>
        <source>Transfer completed partially</source>
        <translation>Chuyển dữ liệu đã hoàn tất một phần</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="32"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="125"/>
        <source>Transfer completed</source>
        <translation>Chuyển dữ liệu đã hoàn tất</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="38"/>
        <source>Partial information migration failed, please go to UOS for manual transfer</source>
        <translation>Chuyển dữ liệu không đầy đủ, vui lòng truy cập UOS để chuyển thủ công</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="50"/>
        <source>Back</source>
        <translation>Quay lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="52"/>
        <source>Exit</source>
        <translation>Thoát</translation>
    </message>
</context>
<context>
    <name>SelectItem</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="216"/>
        <source>Selected:0</source>
        <translation>Đã chọn:0</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="239"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="241"/>
        <source>Selected:%1</source>
        <translation>Đã chọn:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="304"/>
        <source>Edit</source>
        <translation>Chỉnh sửa</translation>
    </message>
</context>
<context>
    <name>SelectMainWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="90"/>
        <source>File</source>
        <translation>Tập tin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="95"/>
        <source>App</source>
        <translation>Ứng dụng</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="97"/>
        <source>Config</source>
        <translation>Cấu hình</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="112"/>
        <source>Back</source>
        <translation>Quay lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="72"/>
        <source>Select data to transfer</source>
        <translation>Chọn dữ liệu để chuyển</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="73"/>
        <source>Please select the content to back up</source>
        <translation>Vui lòng chọn nội dung để sao lưu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="74"/>
        <source>Start transfer</source>
        <translation>Bắt đầu chuyển</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="75"/>
        <source>Next</source>
        <translation>Tiếp theo</translation>
    </message>
</context>
<context>
    <name>SettingHelper</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Profiles</source>
        <translation>Hồ sơ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Wrong or missing profile</source>
        <translation>Hồ sơ sai hoặc thiếu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <source>My Wallpaper</source>
        <translation>Bức tường nền của tôi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="234"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer completed</source>
        <translation>Chuyển đã hoàn tất</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Browser Bookmarks</source>
        <translation>Danh sách bookmark trình duyệt</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <source>BrowserBookMark</source>
        <translation>BrowserBookMark</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="176"/>
        <source>is installed</source>
        <translation>đã được cài đặt</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="200"/>
        <source>Installing</source>
        <translation>Đang cài đặt</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer failed</source>
        <translation>Chuyển thất bại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <source>Format error</source>
        <translation>Lỗi định dạng</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Setup failed, configuration can be imported manually</source>
        <translation>Cài đặt thất bại, cấu hình có thể được nhập thủ công</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="157"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="188"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="238"/>
        <source>Installation failed, please go to the app store to install</source>
        <translation>Cài đặt thất bại, vui lòng truy cập cửa hàng ứng dụng để cài đặt</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="249"/>
        <source>Transfer Complete</source>
        <translation>Chuyển Hoàn tất</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="21"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="22"/>
        <source>Pictures</source>
        <translation>Hình ảnh</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="23"/>
        <source>Documents</source>
        <translation>Tài liệu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="24"/>
        <source>Downloads</source>
        <translation>Tải xuống</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="25"/>
        <source>Music</source>
        <translation>Nhạc</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="26"/>
        <source>Desktop</source>
        <translation>Bàn làm việc</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="80"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="351"/>
        <source>Select:%1</source>
        <translation>Chọn:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="225"/>
        <source>local disk</source>
        <translation>ổ đĩa cục bộ</translation>
    </message>
</context>
<context>
    <name>StartWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="35"/>
        <source>UOS data transfer</source>
        <translation>Chuyển dữ liệu UOS</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="39"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to
UOS, helping you seamlessly replace your system.</source>
        <translation>Công cụ chuyển dữ liệu UOS cho phép di chuyển một cách nhanh chóng các tệp, dữ liệu cá nhân và ứng dụng của bạn sang UOS, giúp bạn thay thế hệ thống một cách mượt mà.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="46"/>
        <source>Next</source>
        <translation>Tiếp theo</translation>
    </message>
</context>
<context>
    <name>TransferHandle</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/transferworker.cpp" line="326"/>
        <source>Transfering</source>
        <translation>Đang chuyển</translation>
    </message>
</context>
<context>
    <name>TransferringWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="42"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="193"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="230"/>
        <source>Transferring...</source>
        <translation>Đang chuyển...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="57"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="191"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="229"/>
        <source>Calculationing...</source>
        <translation>Đang tính toán...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="63"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="132"/>
        <source>Show processes</source>
        <translation>Hiển thị quy trình</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="119"/>
        <source>Hide processes</source>
        <translation>Ẩn quy trình</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="154"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="195"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>Chuyển sẽ hoàn tất trong %1 phút</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="171"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="243"/>
        <source>Transfering</source>
        <translation>Đang chuyển</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="199"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Chuyển sẽ hoàn tất trong %1 giây</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="202"/>
        <source>Transfer will be completed in --</source>
        <translation>Chuyển sẽ hoàn tất trong --</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <source>Decompressing</source>
        <translation>Giải nén</translation>
    </message>
</context>
<context>
    <name>UnzipWorker</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="126"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="137"/>
        <source>Decompressing</source>
        <translation>Giải nén</translation>
    </message>
</context>
<context>
    <name>UploadFileFrame</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="197"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="256"/>
        <source>Drag file here </source>
        <translation>Kéo tệp vào đây </translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="202"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="257"/>
        <source>Import file</source>
        <translation>Nhập tệp</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="276"/>
        <source>Only .zip is supported, please</source>
        <translation>Chỉ hỗ trợ .zip, vui lòng</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="277"/>
        <source>reselect</source>
        <translation>chọn lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>select zip file</source>
        <translation>chọn tệp zip</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>ZIP file (*.zip)</source>
        <translation>Tệp ZIP (*.zip)</translation>
    </message>
</context>
<context>
    <name>UploadFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="40"/>
        <source>Select data transfer file</source>
        <translation>Chọn tệp chuyển dữ liệu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="49"/>
        <source>File error, cannot transfer, please reselect</source>
        <translation>Lỗi tệp, không thể chuyển, vui lòng chọn lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Quay lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="64"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="108"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="113"/>
        <source>Next</source>
        <translation>Tiếp theo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="69"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="76"/>
        <source>Retry</source>
        <translation>Thử lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="122"/>
        <source>The file is corrupted and cannot be migrated. Please replace it with a backup file.</source>
        <translation>Tập tin bị hỏng và không thể di chuyển. Vui lòng thay thế bằng một tập tin dự phòng.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="133"/>
        <source>Insufficient space on UOS. Please reserve at least %1G of space and try again.</source>
        <translation>Không đủ không gian trên UOS. Vui lòng dành ít nhất %1G không gian và thử lại.</translation>
    </message>
</context>
<context>
    <name>UserSelectFileSize</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/userselectfilesize.cpp" line="22"/>
        <source>Calculating</source>
        <translation>Đang tính toán</translation>
    </message>
</context>
<context>
    <name>WaitTransferWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="32"/>
        <source>Waiting for transfer...</source>
        <translation>Đang chờ chuyển dữ liệu...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="37"/>
        <source>Please select the data to transfer on Windows</source>
        <translation>Vui lòng chọn dữ liệu để chuyển trên Windows</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="47"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="98"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="99"/>
        <source>Close</source>
        <translation>Đóng</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="101"/>
        <source>This operation will clear the transmission progress, Do you want to continue.</source>
        <translation>Thao tác này sẽ xóa tiến trình truyền tải, Bạn có muốn tiếp tục không.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="102"/>
        <source>This operation is not recoverable</source>
        <translation>Thao tác này không thể phục hồi</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessResultWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="32"/>
        <source>Exit</source>
        <translation>Thoát</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="49"/>
        <source>Back</source>
        <translation>Quay lại</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="84"/>
        <source>Back up succeed</source>
        <translation>Sao lưu thành công</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="90"/>
        <source>Congratulations, Your Information has been Successfully Backed Up.</source>
        <translation>Chúc mừng, Thông tin của bạn đã được Sao lưu thành công.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="95"/>
        <source>Go to View</source>
        <translation>Đi đến Xem</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="120"/>
        <source>Back up failed</source>
        <translation>Sao lưu thất bại</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="44"/>
        <source>Packing  %1</source>
        <translation>Đang đóng gói %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="53"/>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="101"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>Chuyển dữ liệu sẽ hoàn tất trong %1 phút</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="56"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Chuyển dữ liệu sẽ hoàn tất trong %1 giây</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="84"/>
        <source>Creating Backup File...</source>
        <translation>Đang tạo tập tin dự phòng...</translation>
    </message>
</context>
<context>
    <name>ZipWork</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="283"/>
        <source>%1 File compression failed</source>
        <translation>&apos;%1 Sao lưu tập tin thất bại&apos;</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="213"/>
        <source>Back up file done</source>
        <translation>Sao lưu tập tin hoàn tất</translation>
    </message>
</context>
<context>
    <name>data_transfer_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/linux/mainwindow_p_linux.cpp" line="32"/>
        <source>UOS data transfer</source>
        <translation>Chuyển dữ liệu UOS</translation>
    </message>
</context>
</TS>